@@ -49,6 +49,12 @@ class UniqueKeyTopicAgent:
             logger.debug(f'topic: {topic_name}, get data: {data}, qid: {qid}')
         return data, qid
 
+    def get_batch(self, topic_name, num=1000):
+        q = self._topics[topic_name]
+        data_list = q.get_batch(num=num)
+        logger.debug(f'topic: {topic_name}, return data len{len(data_list)}')
+        return data_list  # [(data1, qid1), (data2, qid2)]
+
     def ack(self, topic_name, qid):
         q = self._topics[topic_name]
         result = q.ack(qid)
